@@ -4,7 +4,7 @@ methods that act upon a transfer function to gain functions such as the
 mass function.
 '''
 
-version = '1.1.1'
+version = '1.1.2'
 
 ###############################################################################
 # Some Imports
@@ -100,6 +100,10 @@ class Perturbations(object):
         transfer_fit:  A string defining which transfer function fit to use. Current options are 'CAMB' and 'EH' (Eistenstein-Hu)
                        Default: transfer_fit = "CAMB"
                        
+        cut_fit:       Whether to forcibly cut the f(sigma) at bounds given by respective papers.
+                       If False, will use function to calculate all values specified in M (may give ridiculous results)
+                       Default: True
+                       
         **kwargs:      There is a placeholder for any additional cosmological parameters, or camb
                        parameters, that one wishes to include. Parameters that aren't used won't
                        break the program, they will just be ignored. Here follows a list of parameters
@@ -154,7 +158,7 @@ class Perturbations(object):
                  transfer_file=None,
                  z=0.0,
                  wdm_mass=None, k_bounds=[0.0000001, 20000.0],
-                 delta_vir=200.0, user_fit='', transfer_fit='CAMB', ** kwargs):
+                 delta_vir=200.0, user_fit='', transfer_fit='CAMB', cut_fit=True, ** kwargs):
         """
         Initializes the cosmology for which to perform the perturbation analysis.      
         """
@@ -222,7 +226,7 @@ class Perturbations(object):
             }
 
         self.update(M=M, mf_fit=mf_fit, k_bounds=k_bounds, transfer_file=transfer_file, wdm_mass=wdm_mass,
-                     delta_vir=delta_vir, user_fit=user_fit, z=z, transfer_fit=transfer_fit, ** kwargs)
+                     delta_vir=delta_vir, user_fit=user_fit, z=z, transfer_fit=transfer_fit, cut_fit=cut_fit, ** kwargs)
 
     def update(self, **kwargs):
         """
@@ -285,8 +289,9 @@ class Perturbations(object):
             elif key is "user_fit":
                 self.user_fit = kwargs['user_fit']
             elif key is "transfer_fit":
-                print "updating transfer_fit"
                 self.transfer_fit = kwargs['transfer_fit']
+            elif key is "cut_fit":
+                self.cut_fit = kwargs['cut_fit']
 
             else:
                 print "WARNING: ", key, " is not a valid parameter for the Perturbations class"
@@ -521,7 +526,7 @@ class Perturbations(object):
             raise IOError("The file " + val + " does not exist or cannot be opened")
 
         #Here we delete properties that are directly dependent on transfer_file
-        del self._lnk_original
+        del self._transfer_original
 
         self.__transfer_file = val
 
@@ -552,8 +557,21 @@ class Perturbations(object):
         if val not in ["CAMB", "EH"]:
             raise ValueError("Sorry the transfer_fit has not been implemented for " + val + ". Please choose 'CAMB' or 'EH'")
 
+        del self._transfer_original
         self.__transfer_fit = val
 
+    @property
+    def cut_fit(self):
+        return self.__cut_fit
+
+    @cut_fit.setter
+    def cut_fit(self, val):
+        if not isinstance(val, bool):
+            raise ValueError("cut_fit must be a bool, " + str(val))
+
+        del self.fsigma
+        self.__cut_fit = val
+
     #--------------------------------  START NON-SET PROPERTIES ----------------------------------------------
     @property
     def dlogM(self):
@@ -1130,7 +1148,9 @@ class Perturbations(object):
 
         vfv = 0.315 * np.exp(-np.abs(self.lnsigma + 0.61) ** 3.8)
         # Conditional on sigma range.
-        vfv[np.logical_or(self.lnsigma < -1.2, self.lnsigma > 1.05)] = np.NaN
+        if self.cut_fit:
+            vfv[np.logical_or(self.lnsigma < -1.2, self.lnsigma > 1.05)] = np.NaN
+
         return vfv
 
     def _nufnu_Warren(self):
@@ -1143,7 +1163,8 @@ class Perturbations(object):
 
         vfv = 0.7234 * ((1.0 / self.sigma) ** 1.625 + 0.2538) * np.exp(-1.1982 / self.sigma ** 2)
 
-        vfv[np.logical_or(self.M < 10 ** 10, self.M > 10 ** 15)] = np.NaN
+        if self.cut_fit:
+            vfv[np.logical_or(self.M < 10 ** 10, self.M > 10 ** 15)] = np.NaN
         return vfv
 
     def _nufnu_Reed03(self):
@@ -1160,7 +1181,8 @@ class Perturbations(object):
 
         vfv = ST_Fit * np.exp(-0.7 / (self.sigma * np.cosh(2.0 * self.sigma) ** 5))
 
-        vfv[np.logical_or(self.lnsigma < -1.7, self.lnsigma > 0.9)] = np.NaN
+        if self.cut_fit:
+            vfv[np.logical_or(self.lnsigma < -1.7, self.lnsigma > 0.9)] = np.NaN
         return vfv
 
     def _nufnu_Reed07(self):
@@ -1184,7 +1206,8 @@ class Perturbations(object):
 
         vfv = A * np.sqrt(2.0 * a / np.pi) * (1.0 + (1.0 / (a * nu ** 2)) ** p + 0.6 * G_1 + 0.4 * G_2) * nu * np.exp(-c * a * nu ** 2 / 2.0 - 0.03 * nu ** 0.6 / (self.n_eff + 3) ** 2)
 
-        vfv[np.logical_or(self.lnsigma < -0.5, self.lnsigma > 1.2)] = np.NaN
+        if self.cut_fit:
+            vfv[np.logical_or(self.lnsigma < -0.5, self.lnsigma > 1.2)] = np.NaN
 
         return vfv
 
@@ -1252,11 +1275,6 @@ class Perturbations(object):
         b_0 = b_func(self.delta_vir)
         c_0 = c_func(self.delta_vir)
 
-#        print "A_0: ", A_0
-#        print "a_0:", a_0
-#        print "b_0:", b_0
-#        print "c_0:", c_0
-
         A = A_0 * (1 + self.z) ** (-0.14)
         a = a_0 * (1 + self.z) ** (-0.06)
         alpha = np.exp(-(0.75 / np.log(self.delta_vir / 75)) ** 1.2)
@@ -1265,7 +1283,10 @@ class Perturbations(object):
 
 
         vfv = A * ((self.sigma / b) ** (-a) + 1) * np.exp(-c / self.sigma ** 2)
-        vfv[np.logical_or(self.lnsigma < -0.6 , self.lnsigma > 0.4)] = np.nan
+
+        if self.cut_fit:
+            vfv[np.logical_or(self.lnsigma < -0.6 , self.lnsigma > 0.4)] = np.nan
+
         return vfv
 
     def _watson_gamma(self):
@@ -1279,7 +1300,8 @@ class Perturbations(object):
 
     def _nufnu_Watson_FoF(self):
         vfv = 0.282 * ((1.406 / self.sigma) ** 2.163 + 1) * np.exp(-1.21 / self.sigma ** 2)
-        vfv[np.logical_or(self.lnsigma < -0.55 , self.lnsigma > 1.31)] = np.NaN
+        if self.cut_fit:
+            vfv[np.logical_or(self.lnsigma < -0.55 , self.lnsigma > 1.31)] = np.NaN
         return vfv
 
     def _nufnu_Watson(self):
@@ -1302,7 +1324,8 @@ class Perturbations(object):
 
         vfv = self._watson_gamma() * A * ((beta / self.sigma) ** alpha + 1) * np.exp(-gamma / self.sigma ** 2)
 
-        vfv[np.logical_or(self.lnsigma < -0.55, self.lnsigma > 1.05)] = np.NaN
+        if self.cut_fit:
+            vfv[np.logical_or(self.lnsigma < -0.55, self.lnsigma > 1.05)] = np.NaN
 
         return vfv
 
@@ -1334,7 +1357,8 @@ class Perturbations(object):
         nu = self.cosmo_params['delta_c'] / self.sigma
 
         vfv = A * np.sqrt(2.0 / np.pi) * np.exp(-(a * nu ** 2) / 2.0) * (1 + (1.0 / (a * nu ** 2)) ** p) * (nu * np.sqrt(a)) ** q
-        vfv[np.logical_or(self.M < 6 * 10 ** 11, self.M > 3 * 10 ** 15)] = np.NaN
+        if self.cut_fit:
+            vfv[np.logical_or(self.M < 6 * 10 ** 11, self.M > 3 * 10 ** 15)] = np.NaN
 
         return vfv
     def _nufnu_user_model(self):
