@@ -42,7 +42,7 @@ def get_transfer(transfer_file, camb_dict, transfer_fit, k_bounds=None):
     if transfer_file is None:
         if transfer_fit == "CAMB":
             k, T, sig8 = pycamb.transfers(**camb_dict)
-            T = np.log(T[[0, 6], :, 0])
+            T = np.log(T[[0, 1], :, 0])
 
             del sig8, k
         elif transfer_fit == "EH":
@@ -71,7 +71,7 @@ def read_transfer(transfer_file):
     """
 
     transfer = np.loadtxt(transfer_file)
-    T = np.log(transfer[:, [0, 6]])
+    T = np.log(transfer[:, [0, 6]]).T
 
     return T
 
